==> codepipeline-actions-1.125.0-sources.jar: software/amazon/awscdk/services/codepipeline/actions/StateMachineInput.java <==
package software.amazon.awscdk.services.codepipeline.actions;

/**
 * Represents the input for the StateMachine.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.34.0 (build 9b72778)", date = "2021-09-29T20:31:34.869Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.codepipeline.actions.$Module.class, fqn = "@aws-cdk/aws-codepipeline-actions.StateMachineInput")
public class StateMachineInput extends software.amazon.jsii.JsiiObject {

    protected StateMachineInput(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected StateMachineInput(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * When the input type is FilePath, input artifact and filepath must be specified.
     * <p>
     * @param inputFile This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codepipeline.actions.StateMachineInput filePath(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codepipeline.ArtifactPath inputFile) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.codepipeline.actions.StateMachineInput.class, "filePath", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codepipeline.actions.StateMachineInput.class), new Object[] { java.util.Objects.requireNonNull(inputFile, "inputFile is required") });
    }

    /**
     * When the input type is Literal, input value is passed directly to the state machine input.
     * <p>
     * @param object This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codepipeline.actions.StateMachineInput literal(final @org.jetbrains.annotations.NotNull com.fasterxml.jackson.databind.node.ObjectNode object) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.codepipeline.actions.StateMachineInput.class, "literal", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codepipeline.actions.StateMachineInput.class), new Object[] { java.util.Objects.requireNonNull(object, "object is required") });
    }

    /**
     * When InputType is set to Literal (default), the Input field is used directly as the input for the state machine execution.
     * <p>
     * Otherwise, the state machine is invoked with an empty JSON object {}.
     * <p>
     * When InputType is set to FilePath, this field is required.
     * An input artifact is also required when InputType is set to FilePath.
     * <p>
     * Default: - none
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.Object getInput() {
        return software.amazon.jsii.Kernel.get(this, "input", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }

    /**
     * The optional input Artifact of the Action.
     * <p>
     * If InputType is set to FilePath, this artifact is required
     * and is used to source the input for the state machine execution.
     * <p>
     * Default: - the Action will not have any inputs
     * <p>
     * @see https://docs.aws.amazon.com/codepipeline/latest/userguide/action-reference-StepFunctions.html#action-reference-StepFunctions-example
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.codepipeline.Artifact getInputArtifact() {
        return software.amazon.jsii.Kernel.get(this, "inputArtifact", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codepipeline.Artifact.class));
    }

    /**
     * Optional StateMachine InputType InputType can be Literal or FilePath.
     * <p>
     * Default: - Literal
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.lang.String getInputType() {
        return software.amazon.jsii.Kernel.get(this, "inputType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}

==> codepipeline-actions-1.201.0-sources.jar: software/amazon/awscdk/services/codepipeline/actions/StateMachineInput.java <==
package software.amazon.awscdk.services.codepipeline.actions;

/**
 * Represents the input for the StateMachine.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * import software.amazon.awscdk.services.stepfunctions.*;
 * Pipeline pipeline = new Pipeline(this, "MyPipeline");
 * Pass startState = new Pass(this, "StartState");
 * StateMachine simpleStateMachine = StateMachine.Builder.create(this, "SimpleStateMachine")
 *         .definition(startState)
 *         .build();
 * StepFunctionInvokeAction stepFunctionAction = StepFunctionInvokeAction.Builder.create()
 *         .actionName("Invoke")
 *         .stateMachine(simpleStateMachine)
 *         .stateMachineInput(StateMachineInput.literal(Map.of("IsHelloWorldExample", true)))
 *         .build();
 * pipeline.addStage(StageOptions.builder()
 *         .stageName("StepFunctions")
 *         .actions(List.of(stepFunctionAction))
 *         .build());
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.74.0 (build 6d08790)", date = "2023-05-10T17:06:03.322Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.codepipeline.actions.$Module.class, fqn = "@aws-cdk/aws-codepipeline-actions.StateMachineInput")
public class StateMachineInput extends software.amazon.jsii.JsiiObject {

    protected StateMachineInput(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected StateMachineInput(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * When the input type is FilePath, input artifact and filepath must be specified.
     * <p>
     * @param inputFile This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codepipeline.actions.StateMachineInput filePath(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codepipeline.ArtifactPath inputFile) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.codepipeline.actions.StateMachineInput.class, "filePath", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codepipeline.actions.StateMachineInput.class), new Object[] { java.util.Objects.requireNonNull(inputFile, "inputFile is required") });
    }

    /**
     * When the input type is Literal, input value is passed directly to the state machine input.
     * <p>
     * @param object This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codepipeline.actions.StateMachineInput literal(final @org.jetbrains.annotations.NotNull com.fasterxml.jackson.databind.node.ObjectNode object) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.codepipeline.actions.StateMachineInput.class, "literal", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codepipeline.actions.StateMachineInput.class), new Object[] { java.util.Objects.requireNonNull(object, "object is required") });
    }

    /**
     * When InputType is set to Literal (default), the Input field is used directly as the input for the state machine execution.
     * <p>
     * Otherwise, the state machine is invoked with an empty JSON object {}.
     * <p>
     * When InputType is set to FilePath, this field is required.
     * An input artifact is also required when InputType is set to FilePath.
     * <p>
     * Default: - none
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.Object getInput() {
        return software.amazon.jsii.Kernel.get(this, "input", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }

    /**
     * The optional input Artifact of the Action.
     * <p>
     * If InputType is set to FilePath, this artifact is required
     * and is used to source the input for the state machine execution.
     * <p>
     * Default: - the Action will not have any inputs
     * <p>
     * @see <a href="https://docs.aws.amazon.com/codepipeline/latest/userguide/action-reference-StepFunctions.html#action-reference-StepFunctions-example">https://docs.aws.amazon.com/codepipeline/latest/userguide/action-reference-StepFunctions.html#action-reference-StepFunctions-example</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.codepipeline.Artifact getInputArtifact() {
        return software.amazon.jsii.Kernel.get(this, "inputArtifact", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codepipeline.Artifact.class));
    }

    /**
     * Optional StateMachine InputType InputType can be Literal or FilePath.
     * <p>
     * Default: - Literal
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.lang.String getInputType() {
        return software.amazon.jsii.Kernel.get(this, "inputType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}
